<?php

namespace Teknisa\PLA\Modules\Requisicao\Services;

class Pla00900RequisicaoExtraService {
	protected $entityManager;
	protected $connection;
	protected $environment;

	public function __construct($entityManager, $connection, $environment){
		$this->entityManager = $entityManager;
		$this->connection = $connection;
		$this->environment = $environment;
	}

	public function deletePrevreti($row){
		$sql = "DELETE FROM PREVRETI
						WHERE
   					(NRORG     = :P_NRORG)   		AND
   					(CDFILIAL     = :P_CDFILIAL)   		AND
   					(CDSERVFILI   = :P_CDSERVFILI) 		AND
   					(DTPREVRETI   = :P_DTPREVRETI) 		AND
   					(IDPREVRETI   = :P_IDPREVRETI) 		AND
   					(NRREQUEXTR   = :P_NRREQUEXTR) 		AND
   					(CDPRATO      = :P_CDPRATO)    		AND
   					(CDFILAUXPRAT = :P_CDFILAUXPRAT)	AND
   					(CDTIPOPRAT   = :P_CDTIPOPRAT)";

		$params = array(
		  'P_NRORG' => $row['NRORG'],
          'P_CDFILIAL' => $row['CDFILIAL'],
          'P_CDSERVFILI' => $row['CDSERVFILI'],
          'P_DTPREVRETI' => $row['DTPREVRETI'],
          'P_IDPREVRETI' => $row['IDPREVRETI'],
          'P_NRREQUEXTR' => $row['NRREQUEXTR'],
          'P_CDPRATO' => $row['CDPRATO'],
          'P_CDFILAUXPRAT' => $row['CDFILAUXPRAT'],
          'P_CDTIPOPRAT' => $row['CDTIPOPRAT']
		);

		$query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
	}
	
	public function importConsumption($row) {
        $sqlInsert = "INSERT INTO PREVRETI ( CDOPERADOR, CDFILIAL, CDSERVFILI, DTPREVRETI, NRREQUEXTR, IDPREVRETI, CDPRODUTO, DTLIMITERETI, HRLIMITERETI, QTPREVRETI, CDSETORCOZ, IDPREVTPPRAT, NRPRPREVRETI, CDTIPOPRAT, CDPRATO, CDFILAUXPRAT ) VALUES ( :P_CDOPERADOR, :P_CDFILIAL, :P_CDSERVFILI, :P_DTPREVRETI, :P_NRREQUEXTR, :P_IDPREVRETI, :P_CDPRODUTO, :P_DTLIMITERETI, :P_HRLIMITERETI, :P_QTPREVRETI, :P_CDSETORCOZ, :P_IDPREVTPPRAT, :P_NRPRPREVRETI, :P_CDTIPOPRAT, :P_CDPRATO, :P_CDFILAUXPRAT)";
        try {
            $std = $this->entityManager->getConnection()->prepare($sqlInsert);
            $std->execute($row);
            
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    /**
    * Função responsável por retornar o nível máximo de produto.
    * 
    * @return   String  Nível máximo de produto.
    */
	public function getMaxNvlProduto() {
        $sql = "SELECT CDPICTPROD FROM PARAMGERAL";

        try {
            $std = $this->entityManager->getConnection()->prepare($sql);
            $std->execute();
            
            return $std->fetchAll()[0]['CDPICTPROD'];
            
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    /**
    * Função responsável por realizar o update da maneira correta caso seja
    * alterada um registro da tabela PREVRETI.
    * 
    * @param    Object  $row    Objeto row contendo os dados a serem gravados.
    */
    public function updatePrevreti($row){
        $sql = "UPDATE
                    PREVRETI
                SET
                    CDTIPOPRAT      = :CDTIPOPRAT,
                    CDPRATO         = :CDPRATO,
                    CDSETORCOZ      = :CDSETORCOZ,
                    CDPRODUTO       = :CDPRODUTO,
                    QTPREVRETI      = :QTPREVRETI,
                    DTLIMITERETI    = :DTLIMITERETI,
                    HRLIMITERETI    = :HRLIMITERETI
                WHERE
                    DTLIMITERETI    = :OLD_DTLIMITERETI AND
                    HRLIMITERETI    = :OLD_HRLIMITERETI AND
                    CDPRODUTO       = :OLD_CDPRODUTO AND
                    IDPREVRETI      = :IDPREVRETI AND
                    CDSERVFILI      = :CDSERVFILI AND
                    CDFILIAL        = :CDFILIAL AND
                    NRORG           = :NRORG";
        
        $params = array(
            "CDFILIAL"          => $row['CDFILIAL'],
            "CDTIPOPRAT"        => $row['CDTIPOPRAT'],
            "CDPRATO"           => $row['CDPRATO'],
            "CDPRODUTO"         => $row['CDPRODUTO'],
            "CDSERVFILI"        => $row['CDSERVFILI'],
            "CDSETORCOZ"        => isset($row['CDSETORCOZ']) ? $row['CDSETORCOZ'] : null,
            "DTLIMITERETI"      => $row['DTLIMITERETI'],
            "HRLIMITERETI"      => $row['HRLIMITERETI'],
            "IDPREVRETI"        => $row['IDPREVRETI'],
            "NRORG"             => $row['NRORG'],
            "OLD_CDPRODUTO"     => $row['OLD_CDPRODUTO'],
            "OLD_DTLIMITERETI"  => $row['OLD_DTLIMITERETI'],
            "OLD_HRLIMITERETI"  => $row['OLD_HRLIMITERETI'],
            "QTPREVRETI"        => floatval($row['QTPREVRETI'])
        );
        
        try {
            
            $std = $this->entityManager->getConnection()->prepare($sql);
            $std->execute($params);
            
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function insertPrevreti($row, $nrreqextr){
        $sql = "INSERT INTO PREVRETI (CDOPERADOR, CDFILIAL, CDSERVFILI, DTPREVRETI, NRREQUEXTR, IDPREVRETI, CDPRODUTO, DTLIMITERETI, HRLIMITERETI, QTPREVRETI, QTPRERETT1, QTPRERETT2, QTPRERETT3, QTPRERETT4, CDSETORCOZ, IDPREVTPPRAT, NRPRPREVRETI, CDTIPOPRAT, CDPRATO, CDFILAUXPRAT)
                VALUES
                (:CDOPERADOR, 
                :CDFILIAL, 
                :CDSERVFILI, 
                :DTPREVRETI, 
                :NRREQUEXTR, 
                :IDPREVRETI, 
                :CDPRODUTO, 
                :DTLIMITERETI, 
                :HRLIMITERETI, 
                :QTPREVRETI, 
                :QTPRERETT1, 
                :QTPRERETT2, 
                :QTPRERETT3, 
                :QTPRERETT4, 
                :CDSETORCOZ, 
                :IDPREVTPPRAT, 
                :NRPRPREVRETI, 
                :CDTIPOPRAT, 
                :CDPRATO, 
                :CDFILAUXPRAT)";

        $params = array(
            "CDOPERADOR"        => $this->environment->getCdOperador(),
            "CDFILIAL"          => $row['CDFILIAL'],
            "CDSERVFILI"        => $row['CDSERVFILI'],
            "DTPREVRETI"        => $row['DTPREVRETI'],
            "NRREQUEXTR"        => $nrreqextr,
            "IDPREVRETI"        => $row['IDPREVRETI'],
            "CDPRODUTO"         => $row['CDPRODUTO'],
            "DTLIMITERETI"      => $row['DTLIMITERETI'], 
            "HRLIMITERETI"      => $row['HRLIMITERETI'], 
            "QTPREVRETI"        => floatval($row['QTPREVRETI']),
            "QTPRERETT1"        => isset($row['QTPRERETT1']) ? floatval($row['QTPRERETT1']) : null,
            "QTPRERETT2"        => isset($row['QTPRERETT2']) ? floatval($row['QTPRERETT2']) : null,
            "QTPRERETT3"        => isset($row['QTPRERETT3']) ? floatval($row['QTPRERETT3']) : null,
            "QTPRERETT4"        => isset($row['QTPRERETT4']) ? floatval($row['QTPRERETT4']) : null,
            "CDSETORCOZ"        => $row['CDSETORCOZ'],
            "IDPREVTPPRAT"      => isset($row['IDPREVTPPRAT']) ? $row['IDPREVTPPRAT'] : null,
            "NRPRPREVRETI"      => $row['NRPRPREVRETI'],
            "CDTIPOPRAT"        => isset($row['CDTIPOPRAT']) ? $row['CDTIPOPRAT'] : null,
            "CDPRATO"           => isset($row['CDPRATO']) ? $row['CDPRATO'] : null,
            "CDFILAUXPRAT"      => isset($row['CDFILAUXPRAT']) ? $row['CDFILAUXPRAT'] : null
        );
        try {
            
            $std = $this->entityManager->getConnection()->prepare($sql);
            $std->execute($params);
            
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function getRowsToDelete($dataSet){
    	$sql = "SELECT NRPRPREVRETI, CDOPERADOR, CDFILIAL, CDSERVFILI, DTPREVRETI, NRREQUEXTR, IDPREVRETI, CDPRODUTO, DTLIMITERETI, HRLIMITERETI, QTPREVRETI, QTPRERETT1, QTPRERETT2, QTPRERETT3, QTPRERETT4, CDSETORCOZ, IDPREVTPPRAT, NRPRPREVRETI, NRORG, CDTIPOPRAT, CDPRATO, CDFILAUXPRAT FROM PREVRETI WHERE CDFILIAL = :CDFILIAL AND CDPRATO = :CDPRATO AND IDPREVRETI = :IDPREVRETI AND NRREQUEXTR = :NRREQUEXTR AND DTPREVRETI = :DTPREVRETI AND CDTIPOPRAT = :CDTIPOPRAT ";
       
        $params = array(
            "CDFILIAL"      => $dataSet[0]['CDFILIAL'],
            "CDTIPOPRAT"    => $dataSet[0]['CDTIPOPRAT'],
            "CDPRATO"   	=> $dataSet[0]['CDPRATO'],
            "IDPREVRETI"	=> $dataSet[0]['IDPREVRETI'],
            "NRREQUEXTR"	=> $dataSet[0]['NRREQUEXTR'],
            "DTPREVRETI"	=> $dataSet[0]['DTPREVRETI']
        );
        
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	return $result = $query->fetchAll();
    }
    
    public function updateTipoDePrato($row){
    	$sql = "UPDATE PREVRETI SET CDSETORCOZ = :CDSETORCOZ, CDTIPOPRAT = :CDTIPOPRAT, CDPRATO = :CDPRATO, CDFILAUXPRAT = :CDFILAUXPRAT WHERE CDFILIAL = :CDFILIAL AND CDPRATO = :OLD_CDPRATO AND IDPREVRETI = :IDPREVRETI AND NRREQUEXTR = :NRREQUEXTR AND CDTIPOPRAT = :OLD_CDTIPOPRAT AND DTPREVRETI = :DTPREVRETI";
       
        $params = array(
            "CDSETORCOZ"        => $row['CDSETORCOZ'],
            "CDTIPOPRAT"        => $row['CDTIPOPRAT'],
            "CDPRATO"           => $row['CDPRATO'],
            "CDFILAUXPRAT"      => $row['CDFILAUXPRAT'],
            "CDFILIAL"          => $row['CDFILIAL'],
            "OLD_CDPRATO"   	=> $row['OLD_CDPRATO'],
            "IDPREVRETI"	    => $row['IDPREVRETI'],
            "NRREQUEXTR"	    => $row['NRREQUEXTR'],
            "OLD_CDTIPOPRAT"    => $row['OLD_CDTIPOPRAT'],
            "DTPREVRETI"        => $row['DTPREVRETI']
        );
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    }
    
    public function updateSetor($row){
    	$sql = "UPDATE PREVRETI SET CDSETORCOZ = :CDSETORCOZ WHERE CDFILIAL = :CDFILIAL AND NRREQUEXTR = :NRREQUEXTR AND CDSERVFILI = :CDSERVFILI";
    	$params = array("CDSETORCOZ" => $row['CDSETORCOZ'],
        				"CDSERVFILI" => $row['CDSERVFILI'],
        				"NRREQUEXTR" => $row['NRREQUEXTR'],
                        "CDFILIAL" => $row['CDFILIAL']);
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
    }
    
    public function verifyExisit($row, $cdproduto){
    	$sql = "SELECT * FROM PREVRETI WHERE NRREQUEXTR = :NRREQUEXTR  AND CDFILIAL = :CDFILIAL AND CDSERVFILI = :CDSERVFILI AND (CDPRODUTO = :CDPRODUTO OR :CDPRODUTO IS NULL) AND (CDTIPOPRAT = :CDTIPOPRAT OR :CDTIPOPRAT IS NULL) AND (CDPRATO = :CDPRATO OR :CDPRATO IS NULL)";
    	$params = array("CDFILIAL" => $row['CDFILIAL'],
        				"NRREQUEXTR" => $row['NRREQUEXTR'],
        				"CDSERVFILI" => $row['CDSERVFILI'],
        				"CDPRODUTO" => $cdproduto,
        				"CDTIPOPRAT" => empty($row['CDTIPOPRAT']) ? null : $row['CDTIPOPRAT'],
        				"CDPRATO" => empty($row['CDPRATO']) ? null : $row['CDPRATO']);
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        return $result = $query->fetchAll();
    }
    
    public function verifyRequest($row){
        
    	$sql = "SELECT * FROM PREVRETI WHERE NRREQUEXTR = :NRREQUEXTR  AND CDFILIAL = :CDFILIAL AND CDSERVFILI = :CDSERVFILI AND DTPREVRETI = :DTPREVRETI AND IDPREVRETI = :IDPREVRETI";
    	$params = array("CDFILIAL" => $row['P_CDFILIAL'],
        				"NRREQUEXTR" => $row['P_NRREQUEXTR'],
        				"CDSERVFILI" => $row['P_CDSERVFILI'],
        				"DTPREVRETI" => $row['P_DTPREVRETI'],
        				"IDPREVRETI" => $row['P_IDPREVRETI']);
	    $query = $this->entityManager->getConnection()->prepare($sql);
	    
        $query->execute($params);
        return $result = $query->fetchAll();
    }
    
    public function insertSetorcoz($row){
        $sql = "INSERT INTO SETORCOZ (CDFILIAL, CDSETORCOZ, NMSETORCOZ, NRORG, NRORGINCLUSAO, NRORGULTATU, CDOPERINCLUSAO, CDOPERULTATU, DTINCLUSAO, DTULTATU) SELECT :CDFILIAL, :CDSETORCOZ, :NMSETORCOZ, :NRORG, :NRORG, :NRORG, :CDOPERADOR, :CDOPERADOR, SYSDATE, SYSDATE FROM DUAL WHERE NOT EXISTS (SELECT 1 FROM SETORCOZ WHERE CDFILIAL = :CDFILIAL AND CDSETORCOZ = :CDSETORCOZ)";
        $params = array(
            "CDFILIAL"      => $row['CDFILIAL'],
            "CDSETORCOZ"    => $row['CDSETORCOZ'],
            "NMSETORCOZ"    => $row['NMSETORCOZ'],
            "NRORG"         => $row['NRORG'],
            "CDOPERADOR"    => $row['CDOPERADOR']);
        try {       
            $query = $this->entityManager->getConnection()->prepare($sql);
            $query->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
}